@@ -40,14 +40,14 @@ class CloudspotLicense_API:
             headers = merged_headers
         else: headers = self.headers
 
-        reqUrl = '{base}/{url}/'.format(base=self.base_url, url=url)
+        request_url = '{base}/{url}/'.format(base=self.base_url, url=url)
 
         if method == 'GET':
-            response = requests.get(reqUrl, params=data, headers=headers)
+            response = requests.get(request_url, params=data, headers=headers)
         elif method == 'POST':
-            response = requests.post(reqUrl, data=json.dumps(data), headers=headers)
+            response = requests.post(request_url, data=json.dumps(data), headers=headers)
         elif method == 'PUT':
-            response = requests.put(reqUrl, data=json.dumps(data), headers=headers)
+            response = requests.put(request_url, data=json.dumps(data), headers=headers)
         
         return response
 
@@ -81,8 +81,6 @@ class CloudspotLicense_API:
         if auth_resp.has_error: raise BadCredentials('Username or password not correct.')
         
         self.permissions = auth_resp.permissions
-        self.user.company_id = auth_resp.company_id
-        self.user.company_name = auth_resp.company_name
         self.set_token_header(auth_resp.token)
 
     def get_permissions(self, token=None):
@@ -97,4 +95,11 @@ class CloudspotLicense_API:
         user_resp = self.auth.get_user()
         if user_resp.has_error: raise NoValidToken('No valid token found.')
         
-        self.user = user_resp
\ No newline at end of file
+        self.user = user_resp
+    
+    def get_company_permissions(self, company_id, token=None):
+        if token: self.set_token_header(token)
+        company_resp = self.auth.get_company_permissions(company_id)
+        if company_resp.has_error: raise Exception(company_resp.error.message)
+        
+        return company_resp.permissions
\ No newline at end of file
