@@ -3,11 +3,15 @@ from .base import BaseModel, ObjectListModel
 class AuthPermission(BaseModel):
     
     def __init__(self,
-      permission=None           
+        company_id=None,
+        company_name=None,
+        permissions=None           
     ):
         super().__init__()
         
-        self.permission = permission
+        self.company_id = company_id
+        self.company_name = company_name
+        self.permissions = permissions
     
 class AuthPermissions(ObjectListModel):
 
@@ -18,26 +22,12 @@ class AuthResponse(BaseModel):
     
     def __init__(self,
         token=None,
-        company_id=None,
-        company_name=None,
         permissions=None
     ):
 
         super().__init__()
 
         self.token = token
-        self.company_id = company_id
-        self.company_name = company_name
-        self.permissions = permissions if permissions else AuthPermissions()
-    
-class PermissionsResponse(BaseModel):
-    
-    def __init__(self,
-        permissions=None
-    ):
-
-        super().__init__()
-        
         self.permissions = permissions if permissions else AuthPermissions()
 
 class User(BaseModel):
@@ -45,9 +35,7 @@ class User(BaseModel):
     def __init__(self,
         first_name=None,
         last_name=None,
-        email=None,
-        company_id=None,
-        company_name=None
+        email=None
     ):
         
         super().__init__()
@@ -55,5 +43,12 @@ class User(BaseModel):
         self.first_name = first_name
         self.last_name = last_name
         self.email = email
-        self.company_id = company_id
-        self.company_name = company_name
\ No newline at end of file
+
+class CompanyPermissionsResponse(BaseModel):
+    def __init__(self,
+        permissions=None
+    ):
+
+        super().__init__()
+        
+        self.permissions = permissions
\ No newline at end of file
